@@ -6,6 +6,9 @@ from dateutil.parser import parse
 def now():
     return datetime.datetime.now().replace(microsecond=0)
 
+def now_min():
+    return datetime.datetime.now().replace(microsecond=0, second=0)
+
 def time2time(value):
     if value is None:
         return None
@@ -68,6 +71,22 @@ def date_time(value):
 
     raise ValueError(f'Unknown datetime "{value}"')
 
+def date_time_min(value):
+    if value is None or value == '':
+        return None
+    if isinstance(value, datetime.datetime):
+        return value
+
+    if isinstance(value, (float, int)):
+        return datetime.datetime.fromtimestamp(value)
+
+    if isinstance(value, str):
+        value = time2time(value)
+        if value:
+            return value
+
+    raise ValueError(f'Unknown datetime "{value}"')
+
 def date(value):
     if value is None or value == '':
         return None
